@@ -8,6 +8,9 @@ import uuid
 import icalendar
 from caldav.lib.python_utilities import to_normal_str
 
+## Global counter.  We don't want to be too verbose on the users, ref https://github.com/home-assistant/core/issues/86938
+fixup_error_loggings = 0
+
 ## Fixups to the icalendar data to work around compatbility issues.
 
 ## TODO:
@@ -94,13 +97,21 @@ def fix(event):
         fixed2 += line + "\n"
 
     if fixed2 != event:
-        logging.error(
-            "Ical data was modified to avoid compatibility issues", exc_info=True
+        global fixup_error_loggings
+        fixup_error_loggings += 1
+        remove_bit = lambda n: n & (n - 1)
+        if not remove_bit(fixup_error_loggings):
+            log = logging.error
+        else:
+            log = logging.debug
+        log(
+            "Ical data was modified to avoid compatibility issues.  (error count: %i - this error is ratelimited)",
+            exc_info=True,
         )
         try:
             import difflib
 
-            logging.error(
+            log(
                 "\n".join(
                     difflib.unified_diff(
                         event.split("\n"), fixed2.split("\n"), lineterm=""
@@ -108,8 +119,8 @@ def fix(event):
                 )
             )
         except:
-            logging.error("Original: \n" + event)
-            logging.error("Modified: \n" + fixed2)
+            log("Original: \n" + event)
+            log("Modified: \n" + fixed2)
 
     return fixed2
 
@@ -128,10 +139,21 @@ def create_ical(ical_fragment=None, objtype=None, language="en_DK", **props):
             objtype = "VEVENT"
         component = icalendar.cal.component_factory[objtype]()
         component.add("dtstamp", datetime.datetime.now(tz=datetime.timezone.utc))
-        component.add("uid", uuid.uuid1())
+        if not props.get("uid") and not "\nUID:" in (ical_fragment or ""):
+            component.add("uid", uuid.uuid1())
         my_instance.add_component(component)
+        ## STATUS should default to NEEDS-ACTION for tasks, if it's not set
+        ## (otherwise we cannot easily add a task to a davical calendar and
+        ## then find it again - ref https://gitlab.com/davical-project/davical/-/issues/281
+        if (
+            not props.get("STATUS")
+            and not "\nSTATUS:" in (ical_fragment or "")
+            and objtype == "VTODO"
+        ):
+            props["STATUS"] = "NEEDS-ACTION"
+
     else:
-        if not ical_fragment.startswith("BEGIN:VCALENDAR"):
+        if not ical_fragment.strip().startswith("BEGIN:VCALENDAR"):
             ical_fragment = (
                 "BEGIN:VCALENDAR\n"
                 + to_normal_str(ical_fragment.strip())
@@ -140,6 +162,7 @@ def create_ical(ical_fragment=None, objtype=None, language="en_DK", **props):
         my_instance = icalendar.Calendar.from_ical(ical_fragment)
         component = my_instance.subcomponents[0]
         ical_fragment = None
+
     for prop in props:
         if props[prop] is not None:
             if isinstance(props[prop], datetime.datetime) and not props[prop].tzinfo:
