@@ -96,18 +96,48 @@ caldav_servers = [
         'password': 'solox',
         'enable': False,
         'incompatibilities': ['no_scheduling', "propfind_allprop_failure", "read_only"],
+    },
+    { #12 - my new davical server
+        'url': 'https://davical.bekkenstenveien53c.oslo.no/caldav.php/',
+        'username': 'testaccount1',
+        'password': 'patriot-sunday-profane',
+        'proxy': 'socks5://localhost:1080/', ## When on IPv4-only network
+        'enable': True,
+        'incompatibilities': [
+            'fragile_sync_tokens', ## no issue raised yet.
+            'fastmail_buggy_noexpand_date_search', ## https://gitlab.com/davical-project/davical/-/issues/280
+            #'isnotdefined_not_working', ## https://gitlab.com/davical-project/davical/-/issues/281
+            'vtodo_datesearch_nodtstart_task_is_skipped_in_closed_date_range',
+        ]
+    },
+    { #13 - radicale (temp test)
+        'url': 'http://localhost:5232/',
+        'username': 'caldavtest',
+        'password': 'dead beef family rock',
+        'enable': False,
+        'incompatibilities': ["no_default_calendar", "non_existing_calendar_found", "no_freebusy_rfc4791", 'no_scheduling', 'text_search_is_case_insensitive', 'text_search_is_exact_match_sometimes', 'combined_search_not_working', "calendar_order", "calendar_color"]
+    },
+    { #14 - SOGo
+        'url': 'https://sogo.bekkenstenveien53c.oslo.no/SOGo/dav/',
+        'username': 'test',
+        'password': 'test',
+        'incompatibilities': ["time_based_sync_tokens", "search_needs_comptype", "fastmail_buggy_noexpand_date_search", "text_search_not_working", "isnotdefined_not_working", 'no_journal', 'no_freebusy_rfc4791'] ## and in addition ... the requests are efficiently rate limited, as it spawns lots of postgresql connections all until a limit
+    },
+    { # 15 - posteo
+        'url': 'https://posteo.de:8443/',
+        'username': 'pycaltest',
+        'password': 'stopped-prototype-frostingA1',
+        'incompatibilities': ['no_scheduling', 'no_mkcalendar', 'no_journal', 'no_recurring_todo', 'no_sync_token'] ## no freebusy?
     }
 ]
 
-if False:
+if True:
     test_xandikos = True
     test_radicale = True
-elif False:
-    caldav_servers = [{'url': 'http://localhost:8080', 'username': 'user', 'password': 'nopass'}]
 elif False:
     for x in caldav_servers:
         x['enable'] = False
-    caldav_servers[2]['enable']=True
+    caldav_servers[1]['enable']=True
 
     test_xandikos = False
     test_radicale = False
